#
# spec file for package nfpm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nfpm
Version:        2.41.2
Release:        1.1
Summary:        Simple deb, rpm, apk and arch linux packager written in Go
License:        MIT
URL:            https://github.com/goreleaser/nfpm
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
nFPM is a simple and 0-dependencies deb, rpm, apk and arch linux packager
written in Go

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.version=%{version} \
   -X main.commit=${COMMIT_HASH} \
   -X main.date=${BUILD_DATE} \
   -X main.builtBy=OBS \
   -X main.treeState=false" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE.md
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sun Jan 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.41.2:
  * test: test centos10, fedora 40+ (#899)
  * ci: release metadata (#882)
  * ci: aur sources archive content (#896)
  * ci: update dependabot config
  * chore(deps): update chglog
  * feat(deps): bump github.com/caarlos0/go-version from 0.1.1 to
    0.2.0
  * feat(deps): bump github.com/invopop/jsonschema from 0.12.0 to
    0.13.0 (#897)
  * ci: publish AUR from sources (#895)
  * chore(deps): bump anchore/sbom-action from 0.17.8 to 0.17.9
    (#894)
  * feat(deps): bump golang.org/x/crypto from 0.23.0 to 0.31.0
    (#893)
  * chore(deps): bump actions/cache from 4.1.2 to 4.2.0 (#892)
  * docs: sponsor logo (#887)
  * feat(deps): bump github.com/stretchr/testify from 1.9.0 to
    1.10.0 (#888)
  * chore(deps): bump anchore/sbom-action from 0.17.7 to 0.17.8
    (#886)
  * feat(deps): bump github.com/Masterminds/semver/v3 from 3.3.0 to
    3.3.1 (#885)
  * fix: testifylint and revive lint issues (#884)
  * chore(deps): remove github.com/xi2/xz (#883)
  * docs: update cmd docs
* Sun Jan 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.41.1:
  * fix: properly close file
  * chore(deps): bump codecov/codecov-action from 4 to 5 (#881)
  * chore(deps): bump anchore/sbom-action from 0.17.6 to 0.17.7
    (#875)
  * ci: updating build scripts (#877)
  * ci: add back dpkg-signed tests
  * ci: update acceptance tests to debian:trixie, remove dpkg-sig
    from tests
  * chore(deps): bump anchore/sbom-action from 0.17.5 to 0.17.6
    (#873)
  * docs: update cmd docs
  * chore(deps): bump anchore/sbom-action from 0.17.3 to 0.17.5
    (#870)
  * chore(deps): bump actions/cache from 4.1.1 to 4.1.2 (#871)
* Fri Oct 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.41.0:
  * docs: fix bad documentation
  * fix: improve init
  * chore(deps): bump anchore/sbom-action from 0.17.2 to 0.17.3
    (#867)
  * feat(deps): bump github.com/klauspost/compress from 1.17.10 to
    1.17.11 (#868)
  * chore(deps): bump actions/cache from 4.1.0 to 4.1.1 (#866)
  * chore(deps): bump sigstore/cosign-installer from 3.6.0 to 3.7.0
    (#865)
  * chore(deps): bump actions/cache from 4.0.2 to 4.1.0 (#864)
  * chore(deps): bump cachix/install-nix-action from 29 to 30
    (#863)
  * docs: fix arch and platform env var examples (#862)
  * chore(deps): bump cachix/install-nix-action from V28 to 29
    (#861)
  * feat(deps): bump github.com/klauspost/compress from 1.17.9 to
    1.17.10 (#860)
  * feat(rpm): support %%config(missingok) (#854)
  * fix: undefined variable 'staging-pkgs' (#858)
  * chore(deps): bump cachix/install-nix-action from V27 to 28
    (#855)
  * docs: update cmd docs
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.40.0:
  * feat(deps): bump github.com/Masterminds/semver/v3 from 3.2.1 to
    3.3.0 (#852)
  * chore(deps): bump anchore/sbom-action from 0.17.1 to 0.17.2
    (#851)
  * feat(deps): bump dario.cat/mergo from 1.0.0 to 1.0.1 (#850)
  * feat(deb): set license field (#849)
  * docs: update cmd docs
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.39.0:
  * build: fix packagers shell on darwin
  * feat: env var substitution in description (#848)
  * build: update flake.nix
  * chore(deps): bump anchore/sbom-action from 0.17.0 to 0.17.1
    (#846)
  * chore(deps): bump sigstore/cosign-installer from 3.5.0 to 3.6.0
    (#845)
  * chore(deps): bump benc-uk/workflow-dispatch from 1.2.3 to 1.2.4
    (#844)
  * chore(deps): bump anchore/sbom-action from 0.16.1 to 0.17.0
    (#843)
  * chore(deps): bump anchore/sbom-action from 0.16.0 to 0.16.1
    (#842)
  * fix(deb): dpkg-sig format (#841)
  * docs: update cmd docs
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.38.0:
  * docs: clarify trailing slash in dst
  * fix: system fs paths on windows (#838)
  * test: centos8 mirrorlist has been down for a long time (#837)
  * fix: rpm doesnt allow dashes in prerelease (#836)
  * fix: better handle files owned by the fs (#834)
  * chore: cleanup
  * docs: update
  * docs: update
  * feat(deps): bump github.com/spf13/cobra from 1.8.0 to 1.8.1
    (#832)
  * feat(deps): bump github.com/klauspost/compress from 1.17.8 to
    1.17.9 (#831)
  * ci: update goreleaser config
  * chore(deps): bump goreleaser/goreleaser-action from 5 to 6
    (#827)
  * chore(deps): bump cachix/install-nix-action from 26 to 27
    (#823)
  * docs: update cmd docs
* Mon Jun 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.37.1:
  * fix: move mod back to go 1.21
  * docs: update cmd docs
  * test: test enumarate
  * chore(deps): update go-rpmutils (#814)
  * docs: update cmd docs
  * feat: support for ipk packages (#818)
  * chore(deps): update go-rpmutils
  * chore(deps): bump golangci/golangci-lint-action from 5 to 6
    (#819)
  * chore(deps): bump anchore/sbom-action from 0.15.10 to 0.15.11
    (#817)
  * chore(deps): bump golangci/golangci-lint-action from 4 to 5
    (#816)
* Mon Jun 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package nfpm: a simple deb, rpm, apk and arch linux packager
  written in Go
